# SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
# SPDX-License-Identifier: GPL-3.0-or-later

from PySide2.QtCore import QObject, Property
from glossaico import (
    APP_NAME,
    APP_COMPONENT_NAME,
    APP_AUTHOR,
    APP_AUTHOR_WEB_ADDR,
    APP_DESCRIPTION,
    APP_URL,
    APP_BUG_URL,
    APP_VERSION,
    APP_COPYRIGHT,
    APP_CREDITS,
)


class QAppInfo(QObject):
    """Class that returns application metadata"""

    def __init__(self, icon_dir: str, license_dir: str):
        QObject.__init__(self)
        self._icon_dir = icon_dir
        self._license_dir = license_dir
        self._data: dict = {}

    def load(self):
        """Populate the application data dictionary"""
        self._data = {
            "displayName": APP_NAME,
            "componentName": APP_COMPONENT_NAME,
            "shortDescription": APP_DESCRIPTION,
            "homepage": APP_URL,
            "bugAddress": APP_BUG_URL,
            "version": APP_VERSION,
            "programLogo": f"{self._icon_dir}/mascot-jetpack-noshadow.svg",
            "authors": [{"name": APP_AUTHOR, "webAddress": APP_AUTHOR_WEB_ADDR}],
            "credits": APP_CREDITS,
            "translators": [],
            "licenses": [
                {"name": "GPL-3.0-or-later", "text": "", "spdx": "GPL-3.0-or-later"}
            ],
            "copyrightStatement": APP_COPYRIGHT,
            "desktopFileName": "org.codeberg.dimkard.glossaico.desktop",
            "otherText": "",
            "dataLicences": {"CC-BY-SA-4.0": "", "Unsplash": ""},
        }

        with open(
            f"{self._license_dir}/GPL-3.0-or-later.txt",
            "r",
            encoding="utf-8",
        ) as file:
            self._data["licenses"][0]["text"] = file.read()

        with open(
            f"{self._license_dir}/CC-BY-SA-4.0.txt",
            "r",
            encoding="utf-8",
        ) as file:
            self._data["dataLicences"]["CC-BY-SA-4.0"] = file.read()

        with open(f"{self._license_dir}/UNSPLASH.txt", "r", encoding="utf-8") as file:
            self._data["dataLicences"]["Unsplash"] = file.read()

    def readAboutData(self):
        """Returns the variant map that represents the about-data information
        of the application which is needed by the QML side
        """
        return self._data

    aboutData = Property("QVariantMap", readAboutData, constant=True)
